@@ -9,21 +9,21 @@
 // or else upgrading old project file will not work
 // reliably.
 // TODO QGIS 4: remove in favor of _QGIS_VERSION
-#define VERSION "3.32.3-Lima"
-#define _QGIS_VERSION "3.32.3-Lima"
+#define VERSION "3.34.2-Prizren"
+#define _QGIS_VERSION "3.34.2-Prizren"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 3323
+//#define VERSION_INT 3342
 // TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
-#define VERSION_INT 33203
-#define _QGIS_VERSION_INT 33203
-#define ABISYM(x) x ## 33203
+#define VERSION_INT 33402
+#define _QGIS_VERSION_INT 33402
+#define ABISYM(x) x ## 33402
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Lima"
+#define RELEASE_NAME "Prizren"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
@@ -31,7 +31,7 @@
 #define QGIS_LIB_SUBDIR "lib"
 #define QGIS_QML_SUBDIR "qml"
 #define CMAKE_INSTALL_PREFIX "/usr"
-#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.32.3"
+#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.34.2"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
@@ -46,14 +46,14 @@
 
 #define QT_PLUGINS_DIR "/usr/lib/qt/plugins"
 
-#define PYTHON_VERSION "3.11.5"
+#define PYTHON_VERSION "3.11.6"
 #define PYTHON_VERSION_MAJOR "3"
 #define PYTHON_VERSION_MINOR "11"
-#define PYTHON_VERSION_PATCH "5"
+#define PYTHON_VERSION_PATCH "6"
 
 #define PROJ_VERSION_MAJOR 9
 #define PROJ_VERSION_MINOR 3
-#define PROJ_VERSION_PATCH 0
+#define PROJ_VERSION_PATCH 1
 
 /* #undef USING_NMAKE */
 
@@ -96,6 +96,8 @@
 
 #define HAVE_QTSERIALPORT
 
+/* #undef HAVE_QTGAMEPAD */
+
 /* #undef HAVE_STATIC_PROVIDERS */
 
 #define HAVE_EPT
@@ -103,12 +105,14 @@
 #define HAVE_COPC
 
 #define HAVE_PDAL_QGIS
-#define PDAL_VERSION "2.5.6"
+#define PDAL_VERSION "2.6.2"
 #define PDAL_VERSION_MAJOR_INT 2
-#define PDAL_VERSION_MINOR_INT 5
+#define PDAL_VERSION_MINOR_INT 6
 #define PDAL_VERSION_MAJOR "2"
-#define PDAL_VERSION_MINOR "5"
-#define PDAL_VERSION_MICRO "6"
+#define PDAL_VERSION_MINOR "6"
+#define PDAL_VERSION_MICRO "2"
+
+#define HAVE_DRACO
 
 #define ENABLE_TESTS
 
